@@ -507,7 +507,7 @@ class tree:
             "[==  ]",
             "[=   ]"
         ]
-            self.spinnerstate+=0.1
+            self.spinnerstate+=0.5
             if self.spinnerstate > len(spinner)-1:
                 self.spinnerstate = 0
             curses.textpad.rectangle(stdscr, 0,0,2, maxx-1)
@@ -725,9 +725,9 @@ def main():
 
     tree_grow = mixer.Sound(RES_FOLDER/ "growth.waw")
 
-    seconds = 1
+    seconds = 5
     anilen = 1
-    anispeed = 0.2
+    anispeed = 1
 
     music_volume = 0
     music_volume_max = 1
@@ -738,13 +738,21 @@ def main():
     tree1 = tree(stdscr, 1)
     mixer.music.play(-1)
 
-    treedata_in = open(RES_FOLDER/ "treedata", "rb")
-    tree1.age = pickle.load(treedata_in)
+    try:
+
+        treedata_in = open(RES_FOLDER/ "treedata", "rb")
+        tree1.age = pickle.load(treedata_in)
+
+    except:
+
+        tree1.age = 1
 
 
     try:
         while run:
 
+            start = time.time()
+
             try:
                 stdscr.erase()
                 maxy, maxx = stdscr.getmaxyx()
@@ -754,9 +762,7 @@ def main():
                 if anilen > 150:
                     anilen = 150
 
-                if (
-                    seconds % (100 * 60 * 10) == 0
-                ):  # show another quote every 5 min, and grow tree
+                if (seconds % (100 * 60 * 10) == 0):  # show another quote every 5 min, and grow tree
                     quote = getqt()
                     tree1.age += 1
                     anilen = 1
@@ -829,6 +835,8 @@ def main():
                             os.remove(file)
                         exit()
 
+                    time.sleep(0.1)
+
                 while tree1.isbreak:
                     stdscr.erase()
                     stdscr.addstr(
@@ -856,8 +864,12 @@ def main():
                             os.remove(file)
                         exit()
 
-                time.sleep(0.01)
-                seconds += 1
+                    time.sleep(0.1)
+
+                time.sleep(max(0.05 - (time.time() - start), 0))
+
+                #time.sleep(0.1)
+                seconds += 5
 
             except KeyboardInterrupt:
 
